.. Copyright 2020-2021 Lawrence Livermore National Security, LLC and other
   Hatchet Project Developers. See the top-level LICENSE file for details.

   SPDX-License-Identifier: MIT

******************************
Publications and Presentations
******************************

Publications
============

- Stephanie Brink, Ian Lumsden, Connor Scully-Allison, Katy Williams, Olga Pearce, Todd Gamblin, Michela Taufer, Katherine Isaacs, Abhinav Bhatele. `Usability and Performance Improvements in Hatchet <https://pssg.cs.umd.edu/assets/papers/2020-11-hatchet-protools.pdf>`_. Presented at the `ProTools 2020 Workshop <https://protools20.github.io/>`_, held in conjunction with the International Conference for High Performance Computing, Networking, Storage and Analysis (SC '20), held virtually.

- Abhinav Bhatele, Stephanie Brink, and Todd Gamblin. `Hatchet: Pruning the Overgrowth in Parallel Profiles <https://doi.org/10.1145/3295500.3356219>`_. In Proceedings of the International Conference for High Performance Computing, Networking, Storage and Analysis (SC '19), Denver, CO.

Posters
=======

- Ian Lumsden. `Graph-Based Profiling Analysis using Hatchet <https://globalcomputing.group/assets/img/sc20/posters/ian.pdf>`_. Presented at SC '20. `Slides <https://globalcomputing.group/assets/img/sc20/bestposters/ian.pdf>`_ | `Video Presentation <https://www.youtube.com/watch?v=j-FRGnLBo4U&feature=youtu.be>`_

- Suraj P. Kesavan, Harsh Bhatia, Abhinav Bhatele, Stephanie Brink, Olga Pearce, Todd Gamblin, Peer-Timo Bremer, and Kwan-Liu Ma. `Scalable Comparative Visualization of Ensembles of Call Graphs Using CallFlow`. Presented at SC '20.

Tutorials
=========

- Performance Analysis using Hatchet, LLNL, July 29/31, 2020.
